parse_go_template

Function parse_go_template 

pub fn parse_go_template(source: &str) -> Option<Tree>
Parse source with the tree-sitter Go-template grammar. This crate is the single owner of the raw Go-template tree parse; helm-schema-ast re-exports this function and layers the typed expression AST on top.